@@ -6,12 +6,20 @@ use warnings;
 
 use LWP::UserAgent;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 NAME
 
 Template::Provider::HTTP - fetch templates from a webserver
 
+=begin html
+
+<a href="https://travis-ci.org/evdb/template-provider-http">
+  <img src="https://secure.travis-ci.org/evdb/template-provider-http.png?branch=master" alt="Build status" />
+</a>
+
+=end html
+
 =head1 SYNOPSIS
 
     use Template;
@@ -167,6 +175,14 @@ sub _template_content {
 
 L<Template::Provider> - which this module inherits from.
 
+=head1 BUGS AND REPO
+
+This code is hosted on GitHub:
+
+code: https://github.com/evdb/template-provider-http
+
+bugs: https://github.com/evdb/template-provider-http/issues
+
 =head1 AUTHOR
 
 Edmund von der Burg C<<evdb@ecclestoad.co.uk>>
